@@ -6,7 +6,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client;
-$BZ::Client::VERSION = '1.064';
+$BZ::Client::VERSION = '1.07';
 use BZ::Client::XMLRPC();
 use HTTP::Cookies();
 
@@ -27,6 +27,16 @@ sub url {
     }
 }
 
+sub api_key {
+    my $self = shift;
+    if (@_) {
+        $self->{'api_key'} = shift;
+    }
+    else {
+        return $self->{'api_key'};
+    }
+}
+
 sub user {
     my $self = shift;
     if (@_) {
@@ -47,6 +57,18 @@ sub password {
     }
 }
 
+sub autologin {
+    my $self = shift;
+    if (@_) {
+        $self->{'autologin'} = shift;
+    }
+    else {
+        $self->{'autologin'} = 1
+           unless defined($self->{'autologin'});
+        return $self->{'autologin'};
+    }
+}
+
 sub error {
     my ( $self, $message, $http_code, $xmlrpc_code ) = @_;
     require BZ::Client::Exception;
@@ -66,9 +88,12 @@ sub log {
 }
 
 sub logger {
-    my ($self) = shift;
+    my $self = shift;
     if (@_) {
-        $self->{'logger'} = shift;
+        my $logger = shift;
+        $self->error('Cannot set logger to non-coderef.')
+            unless ref $logger eq 'CODE';
+        $self->{'logger'} = $logger;
     }
     else {
         return $self->{'logger'};
@@ -76,7 +101,7 @@ sub logger {
 }
 
 sub logDirectory {
-    my ($self) = shift;
+    my $self = shift;
     if (@_) {
         $self->{'logDirectory'} = shift;
     }
@@ -106,26 +131,41 @@ sub xmlrpc {
 
 sub login {
     my $self = shift;
-    my $user = $self->user()
-      or $self->error('The Bugzilla servers user name is not set.');
-    my $password = $self->password()
-      or $self->error('The Bugzilla servers password is not set.');
-
-    my $params = {
-        'login'    => $user,
-        'password' => $password,
-        'remember' => BZ::Client::XMLRPC::boolean->new(0)
-    };
+    my $rl = BZ::Client::XMLRPC::boolean->new($self->{'restrictlogin'} ? 1 : 0);
+    my %params = (
+        'remember'       => BZ::Client::XMLRPC::boolean->new(0), # dropped in 5.0
+        'restrictlogin'  => $rl, # added in 3.6
+        'restrict_login' => $rl, # added in 5.0
+    );
+    if (my $api_key = $self->api_key()) {
+        $params{api_key} = $api_key;
+        $self->log( 'debug', 'BZ::Client::login, going to log in with api_key' );
+    }
+    else {
+        my $user = $self->user()
+            or $self->error('The Bugzilla servers user name is not set.');
+        my $password = $self->password()
+            or $self->error('The Bugzilla servers password is not set.');
+        $params{login} = $user;
+        $params{password} = $password;
+        $self->log( 'debug', 'BZ::Client::login, going to log in with username and password' );
+    }
     my $cookies = HTTP::Cookies->new();
-    my $response = $self->_api_call( 'User.login', $params, $cookies );
+    my $response = $self->_api_call( 'User.login', \%params, $cookies );
     if ( not defined( $response->{'id'} )
         or $response->{'id'} !~ m/^\d+$/s )
     {
         $self->error('Server did not return a valid user ID.');
     }
-    $self->{'cookies'} = $cookies;
-
-    return
+    $self->log( 'debug', 'BZ::Client::login, got ID ' . $response->{'id'} );
+    if ( my $token = $response->{'token'} ) { # from 4.4.3
+        $self->{'token'} = $token;
+        $self->log( 'debug', 'BZ::Client::login, got token ' . $token );
+    }
+    else {
+        $self->{'cookies'} = $cookies;
+    }
+    return 1
 }
 
 sub logout {
@@ -140,14 +180,16 @@ sub logout {
 
 sub is_logged_in {
     my $self = shift;
-    return ( $self->{'cookies'} or $self->{'payload'} ) ? 1 : 0
+    return ( $self->{'cookies'} or $self->{'token'} ) ? 1 : 0
 }
 
 sub api_call {
     my ( $self, $methodName, $params ) = @_;
-    if ( !$self->is_logged_in() ) {
+    $params ||= {};
+    if ( $self->autologin && not $self->is_logged_in() ) {
         $self->login();
     }
+
     return $self->_api_call( $methodName, $params )
 }
 
@@ -164,6 +206,8 @@ sub _api_call {
     if ($cookies) {
         $xmlrpc->user_agent()->cookie_jar($cookies);
     }
+    $params->{token} = $self->{'token'}
+        if ($self->{'token'} and not $params->{token});
 
     my $response =
       $xmlrpc->request( 'methodName' => $methodName, params => [$params] );
@@ -196,13 +240,15 @@ BZ::Client - A client for the Bugzilla web services API.
 
 =head1 VERSION
 
-version 1.064
+version 1.07
 
 =head1 SYNOPSIS
 
-  my $client = BZ::Client->new( url      => $url,
-                                user     => $user,
-                                password => $password );
+  my $client = BZ::Client->new( url       => $url,
+                                user      => $user,
+                                password  => $password,
+                                autologin => 0
+                                );
   $client->login();
 
 =head1 CLASS METHODS
@@ -215,11 +261,14 @@ This section lists the class methods of BZ::Client.
                                 user     => $user,
                                 password => $password );
 
+  my $client = BZ::Client->new( url      => $url,
+                                api_key  => $api_key );
+
 The new method constructs a new instance of BZ::Client. Whenever you
 want to connect to the Bugzilla server, you must first create a
 Bugzilla client. The methods input is a hash of parameters.
 
-For debuggign, you can pass in a subref named I<logger> which will be
+For debugging, you can pass in a subref named I<logger> which will be
 fed debugging information as the client works. Also the I<logDirectory>
 option is a directory where the raw http content will be dumped.
 
@@ -229,6 +278,13 @@ option is a directory where the raw http content will be dumped.
 
 The Bugzilla servers URL, for example C<https://bugzilla.mozilla.org/>.
 
+=item api_key
+
+API keys were introduced in 5.0.
+
+You can set up an API key by using the 'API Key' tab in the Preferences
+pages in your Bugzilla install.
+
 =item user
 
 The user name to use when logging in to the Bugzilla server. Typically,
@@ -238,6 +294,24 @@ this will be your email address.
 
 The password to use when logging in to the Bugzilla server.
 
+=item autologin
+
+If set to 1 (true), will try to log in (if not already logged in) when
+the first API call is made. This is default.
+
+If set to 0, will try APi calls without logging in. You can
+still call $client->login() to log in manually.
+
+Note: once you're logged in, you'll stay that way until you call I<logout>
+
+=item restrictlogin
+
+If set to 1 (true), will ask Bugzilla to restrict logins to your IP only.
+Generally this is a good idea, but may caused problems if you are using
+a loadbalanced forward proxy.
+
+Default: 0
+
 =back
 
 =head1 INSTANCE METHODS
@@ -267,10 +341,50 @@ server. Typically, this will be your email address.
 
 Returns or sets the password to use when logging in to the Bugzilla server.
 
+=head2 autologin
+
+If I<login> is automatically called, or not.
+
 =head2 login
 
-Used to login to the Bugzilla server. There is no need to call this method
-explicitly: It is done automatically, whenever required.
+Used to login to the Bugzilla server. By default, there is no need to call
+this method explicitly: It is done automatically, whenever required.
+
+If I<autologin> is set to 0, call this to log in.
+
+=head2 is_logged_in
+
+Returns 1 if logged in, otherwise 0
+
+=head2 logout
+
+Deletes local cookies and calls bugzilla's logout function
+
+=head2 logger
+
+Sets or gets the logging function. Argument is a coderef. Returns undef if none.
+
+  my $logger = $client->logger();
+
+  $client->logger(
+      sub {
+          my ($level, $msg) = @_;
+          print STDERR "$level $message\n";
+          return 1
+      });
+
+Also can be set via new(), e.g.
+
+  $client = BZ::Client->new( logger => sub { },
+                             url    => $url
+                             user   => $user,
+                             password => $password );
+
+=head2 log
+
+  $client->log( $level, $message );
+
+Sends log messages to whatever is loaded via I<logger>.
 
 =head2 api_call
 
