@@ -1,45 +1,41 @@
 #!/bin/false
 # PODNAME: BZ::Client::Bugzilla
-# ABSTRACT: Provides access to the Bugzilla::Webservices::Bugzilla API
+# ABSTRACT: Information about the Bugzilla server, i.e. the Bugzilla::Webservices::Bugzilla API
 
 use strict;
 use warnings 'all';
 
 package BZ::Client::Bugzilla;
-$BZ::Client::Bugzilla::VERSION = '1.064';
+$BZ::Client::Bugzilla::VERSION = '1.07';
 use BZ::Client::API();
 
 our @ISA = qw(BZ::Client::API);
 
 sub extensions {
     my($class, $client) = @_;
-    my $params = {};
-    return $class->api_call($client, 'Bugzilla.extensions', $params);
+    return $class->api_call($client, 'Bugzilla.extensions');
 }
 
 sub time {
     my($class, $client) = @_;
-    my $params = {};
     $client->log('debug', 'BZ::Client::Bugzilla::time: Asking');
-    my $time = $class->api_call($client, 'Bugzilla.time', $params);
+    my $time = $class->api_call($client, 'Bugzilla.time');
     $client->log('debug', 'BZ::Client::Bugzilla::time: Got $time');
     return $time
 }
 
 sub timezone {
     my($class, $client) = @_;
-    my $params = {};
     $client->log('debug', 'BZ::Client::Bugzilla::timezone: Asking');
-    my $timezone = $class->api_call($client, "Bugzilla.timezone", $params);
+    my $timezone = $class->api_call($client, 'Bugzilla.timezone');
     $client->log('debug', 'BZ::Client::Bugzilla::time: Got $timezone');
     return $timezone
 }
 
 sub version {
     my($class, $client) = @_;
-    my $params = {};
     $client->log('debug', 'BZ::Client::Bugzilla::version: Asking');
-    my $version = $class->api_call($client, 'Bugzilla.version', $params);
+    my $version = $class->api_call($client, 'Bugzilla.version');
     $client->log('debug', 'BZ::Client::Bugzilla::time: Got $version');
     return $version
 }
@@ -54,11 +50,11 @@ __END__
 
 =head1 NAME
 
-BZ::Client::Bugzilla - Provides access to the Bugzilla::Webservices::Bugzilla API
+BZ::Client::Bugzilla - Information about the Bugzilla server, i.e. the Bugzilla::Webservices::Bugzilla API
 
 =head1 VERSION
 
-version 1.064
+version 1.07
 
 =head1 SYNOPSIS
 
