@@ -6,7 +6,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::Product;
-$BZ::Client::Product::VERSION = '1.064';
+$BZ::Client::Product::VERSION = '1.07';
 use BZ::Client::API();
 
 our @ISA = qw(BZ::Client::API);
@@ -37,7 +37,7 @@ sub get_accessible_products {
 
 sub get_list {
     my($class, $methodName, $client) = @_;
-    my $result = $class->api_call($client, $methodName, {});
+    my $result = $class->api_call($client, $methodName);
     my $ids = $result->{'ids'};
     if (!$ids  ||  'ARRAY' ne ref($ids)) {
         $class->error($client, 'Invalid reply by server, expected array of ids.');
@@ -119,7 +119,7 @@ BZ::Client::Product - Client side representation of a product in Bugzilla
 
 =head1 VERSION
 
-version 1.064
+version 1.07
 
 =head1 SYNOPSIS
 
