@@ -6,7 +6,7 @@ use strict;
 use warnings 'all';
 
 package BZ::Client::XMLRPC;
-$BZ::Client::XMLRPC::VERSION = '1.064';
+$BZ::Client::XMLRPC::VERSION = '1.07';
 use LWP();
 use XML::Writer();
 use Encode;
@@ -23,7 +23,7 @@ sub new {
     my $class = shift;
     my $self = { @_ };
     bless($self, ref($class) || $class);
-    return $self;
+    return $self
 }
 
 sub url {
@@ -265,14 +265,14 @@ sub logDirectory {
 }
 
 package BZ::Client::XMLRPC::int;
-$BZ::Client::XMLRPC::int::VERSION = '1.064';
+$BZ::Client::XMLRPC::int::VERSION = '1.07';
 sub new {
     my($class, $value) = @_;
     return bless(\$value, (ref($class) || $class))
 }
 
 package BZ::Client::XMLRPC::boolean;
-$BZ::Client::XMLRPC::boolean::VERSION = '1.064';
+$BZ::Client::XMLRPC::boolean::VERSION = '1.07';
 sub new {
     my($class, $value) = @_;
     return bless(\$value, (ref($class) || $class))
@@ -282,7 +282,7 @@ use constant TRUE => BZ::Client::XMLRPC::boolean->new(1);
 use constant FALSE => BZ::Client::XMLRPC::boolean->new(0);
 
 package BZ::Client::XMLRPC::double;
-$BZ::Client::XMLRPC::double::VERSION = '1.064';
+$BZ::Client::XMLRPC::double::VERSION = '1.07';
 sub new {
     my($class, $value) = @_;
     return bless(\$value, (ref($class) || $class))
@@ -302,7 +302,7 @@ BZ::Client::XMLRPC - Performs XML-RPC calls on behalf of the client.
 
 =head1 VERSION
 
-version 1.064
+version 1.07
 
 =head1 SYNOPSIS
 
